@@ -1,10 +1,10 @@
 
 dialogId("dlg-x-poster1", "font_poster", "Greetings from the rubbish heap to our beloved boss.")
-dialogStr("Salutations depuis le tas d'immondices  notre patron bien-aim.")
+dialogStr("Salutations depuis le tas d'immondices ŕ notre patron bien-aimé.")
 
 
 dialogId("dlg-x-poster2", "font_poster", "Yours sincerely")
-dialogStr("Vos trs dvous")
+dialogStr("Vos trčs dévoués")
 
 
 dialogId("dlg-x-poster3", "font_poster", "Agents")
@@ -12,5 +12,5 @@ dialogStr("Agents")
 
 
 dialogId("dlg-x-poster4", "font_poster", "PS: It's great to be here. We irradiate ourselves and swim in the sea a lot. We have many new friends.")
-dialogStr("PS: C'est maginfique d'tre ici. Nous nous sommes irradis et nos nageons beaucoup. Nous avons beaucoup de nouveaux amis.")
+dialogStr("PS: C'est formidable d'ętre ici. Nous nous sommes irradiés et nous nageons beaucoup. Nous avons beaucoup de nouveaux amis.")
 
