@@ -1,5 +1,5 @@
 
-dialogId("odp-v-kachna", "font_big", "Doesn`t this duck look suspicious to you?")
+dialogId("odp-v-kachna", "font_big", "Doesn’t this duck look suspicious to you?")
 dialogStr("Non ti sembra sospetta questa papera?")
 
 dialogId("odp-m-zda0", "font_small", "I think it looks dumb.")
