@@ -1,4 +1,4 @@
 
 dialogId("dlg-x-poster1", "font_poster", "After much hardship we succeeded in finding captain Silver's map. Initial enthusiasm afterwards changed into bitter disappointment, when we found out that the above mentioned map does not indicate the location of the treasure, but the place of residence of the last surviving Silver's parrot that, unfortunately, suffers from sclerosis and cannot remember, where the treasure is.")
-dialogStr("Met veel moeite zijn we erin geslaagd de schatkaart van kapitein Silver te vinden. Ons enthousiasme veranderde al snel in teleurstelling toen we erachter kwamen dat de bovengenoemde kaart niet de positie van de schat geeft, maar de positie van de enige nog levende papegaai van Silver. Helaas lijdt het diertje aan sclerose en heeft het geen idee waar de schat is.")
+dialogStr("Met veel moeite zijn we erin geslaagd de schatkaart van kapitein Silver te vinden. Ons enthousiasme veranderde al snel in teleurstelling toen we erachter kwamen dat de bovengenoemde kaart niet de positie van de schat aangeeft, maar de positie van de enige nog levende papegaai van Silver. Helaas lijdt het diertje aan sclerose en heeft het geen idee waar de schat is.")
 
