@@ -1,11 +1,11 @@
 
 dialogId("uts-m-otresy", "font_small", "My goodness, the impact created cave-in!")
 
-dialogId("uts-v-projet0", "font_big", "I can`t go through this cave-in, we have to find another exit.")
+dialogId("uts-v-projet0", "font_big", "I can’t go through this cave-in, we have to find another exit.")
 
 dialogId("uts-v-projet1", "font_big", "This is not the way.")
 
-dialogId("uts-v-sam", "font_big", "I won`t make it alone.")
+dialogId("uts-v-sam", "font_big", "I won’t make it alone.")
 
 dialogId("uts-m-lastura", "font_small", "I probably should have had lifted that shell first.")
 
@@ -17,7 +17,7 @@ dialogId("uts-m-snek", "font_small", "Now we can drop the snail on the mattress.
 
 dialogId("uts-m-nezvedneme", "font_small", "It will be difficult to pick up that snail from there.")
 
-dialogId("uts-v-konecne", "font_big", "Finally, it`s there.")
+dialogId("uts-v-konecne", "font_big", "Finally, it’s there.")
 
 dialogId("uts-m-chudak", "font_small", "The poor snail...")
 
@@ -25,7 +25,7 @@ dialogId("uts-v-koraly", "font_big", "We should search the coral reefs.")
 
 dialogId("uts-m-tvorove", "font_small", "There are going to be many interesting beings to investigate there.")
 
-dialogId("uts-v-mikroskop", "font_big", "Don`t we need a microscope to investigate corals?")
+dialogId("uts-v-mikroskop", "font_big", "Don’t we need a microscope to investigate corals?")
 
 dialogId("uts-m-zivocich", "font_small", "Yes, they are small. But there can be other life forms.")
 
