@@ -13,3 +13,8 @@ select_addFlag("it", "images/menu/flags/it.png")
 select_addFlag("pl", "images/menu/flags/pl.png")
 select_addFlag("es", "images/menu/flags/es.png")
 select_addFlag("nl", "images/menu/flags/nl.png")
+select_addFlag("bg", "images/menu/flags/bg.png")
+select_addFlag("sv", "images/menu/flags/sv.png")
+select_addFlag("sl", "images/menu/flags/sl.png")
+select_addFlag("pt_BR", "images/menu/flags/pt_br.png")
+select_addFlag("ru", "images/menu/flags/ru.png")
