@@ -3,15 +3,15 @@ dialogId("sch-m-spadlo", "font_small", "Something fell here again.")
 dialogStr("Co nám to sem zase spadlo?")
 
 
-dialogId("sch-v-lastura", "font_big", "It`s some kind of shell. We`ll probably have to push it upstairs again.")
+dialogId("sch-v-lastura", "font_big", "It’s some kind of shell. We’ll probably have to push it upstairs again.")
 dialogStr("Nějaká lastura. Asi ji budem muset vystrkat nahoru.")
 
 
-dialogId("sch-v-setkani", "font_big", "I can see it now: 'Shell Meets Flowerpot`. That`s almost like an iron and a sewing machine meeting on an operating table.")
+dialogId("sch-v-setkani", "font_big", "I can see it now: 'Shell Meets Flowerpot’. That’s almost like an iron and a sewing machine meeting on an operating table.")
 dialogStr("Setkání lastury s květináčem. To je skoro jako setkání žehličky s šicím strojem na operačním stole.")
 
 
-dialogId("sch-m-moc0", "font_small", "I`m sorry, I got a bit carried away.")
+dialogId("sch-m-moc0", "font_small", "I’m sorry, I got a bit carried away.")
 dialogStr("Nějak jsem se do toho moc zabrala.")
 
 
