@@ -3,15 +3,15 @@ dialogId("sch-m-spadlo", "font_small", "Something fell here again.")
 dialogStr("Algo cayó aquí de nuevo.")
 
 
-dialogId("sch-v-lastura", "font_big", "It`s some kind of shell. We`ll probably have to push it upstairs again.")
+dialogId("sch-v-lastura", "font_big", "It’s some kind of shell. We’ll probably have to push it upstairs again.")
 dialogStr("Es alguna clase de concha. Quizás tengamos que empujarla escaleras arriba de nuevo.")
 
 
-dialogId("sch-v-setkani", "font_big", "I can see it now: 'Shell Meets Flowerpot`. That`s almost like an iron and a sewing machine meeting on an operating table.")
+dialogId("sch-v-setkani", "font_big", "I can see it now: 'Shell Meets Flowerpot’. That’s almost like an iron and a sewing machine meeting on an operating table.")
 dialogStr("Lo puedo ver ahora: 'La Concha Conoce al Macetero'. Eso es casi como una plancha y una cortadora de pasto conociéndose en una mesa de operaciones.")
 
 
-dialogId("sch-m-moc0", "font_small", "I`m sorry, I got a bit carried away.")
+dialogId("sch-m-moc0", "font_small", "I’m sorry, I got a bit carried away.")
 dialogStr("Lo siento. Lo dejé ir un poco.")
 
 
