@@ -1,6 +1,6 @@
 
 dialogId("dlg-x-poster1", "font_poster", "We succeeded in capturing dangerous coral completely harmless turtle.")
-dialogStr("Het is ons gelukt om levensgevaarlijke koralen en een onschuldige schildpad te vangen.")
+dialogStr("Het is ons gelukt om levensgevaarlijke koralen en een compleet onschuldige schildpad te vangen.")
 
 
 dialogId("dlg-x-poster2", "font_poster", "We recommend maximum security not necessary to guard measures she's really kind. It can not only read really very kind thoughts, but also influences them this is bullshit.")
@@ -8,5 +8,5 @@ dialogStr("We raden zware beveiliging niet nodig om te bewaken hij is erg lief.
 
 
 dialogId("dlg-x-poster3", "font_poster", "And she has bitten us, too so what. By all means, unmuzzle her only if she wants to do not unmuzlle her.")
-dialogStr("En hij heeft ons ook gebeten, ofzo. Doe de muilkorf alleen af als hij dat wil onder geen enkele omstandigheden af.")
+dialogStr("En hij heeft ons ook gebeten, ofzo. Doe de muilkorf alleen af als hij dat wil onder geen enkele voorwaarden af.")
 
