@@ -13,23 +13,23 @@ node_bestSolution("party1", 236, "Mark Byers")
 node_bestSolution("elk", 257, "Pavel Danihelka")
 node_bestSolution("wreck", 91, "Hynek Vychodil")
 node_bestSolution("viking1", 119, "Pavel Danihelka")
-node_bestSolution("airplane", 239, "Gabor Braun")
+node_bestSolution("airplane", 237, "Johan Rönnblom")
 node_bestSolution("bathyscaph", 82, "Pavel Danihelka")
 node_bestSolution("tank", 402, "Josef Peterka")
 node_bestSolution("viking2", 349, "Gabor Braun")
 node_bestSolution("party2", 283, "Gabor Braun")
-node_bestSolution("gods", 943, "Josef Peterka")
+node_bestSolution("gods", 593, "Gabor Braun")
  
 node_bestSolution("elevator1", 200, "Pavel Danihelka")
-node_bestSolution("city", 483, "Gabor Braun")
-node_bestSolution("ufo", 285, "Gabor Braun")
+node_bestSolution("city", 481, "Gabor Braun")
+node_bestSolution("ufo", 283, "Gabor Braun")
 node_bestSolution("columns", 283, "Josef Peterka")
 node_bestSolution("pavement", 528, "Gabor Braun")
-node_bestSolution("pyramid", 248, "Charles Goodwin")
+node_bestSolution("pyramid", 246, "Johan Rönnblom")
 node_bestSolution("music", 393, "Josef Peterka")
 node_bestSolution("crabshow", 340, "Gabor Braun")
-node_bestSolution("elevator2", 469, "Josef Peterka")
-node_bestSolution("atlantis", 573, "Uoti Urpala")
+node_bestSolution("elevator2", 455, "Gabor Braun")
+node_bestSolution("atlantis", 531, "Uoti Urpala")
  
 node_bestSolution("corals", 256, "Josef Peterka")
 node_bestSolution("labyrinth", 278, "Mark Byers")
@@ -37,8 +37,8 @@ node_bestSolution("imprisoned", 275, "Josef Peterka")
 node_bestSolution("society", 114, "Gabor Braun")
 node_bestSolution("creatures", 447, "Josef Peterka")
 node_bestSolution("cancan", 578, "Mark Byers")
-node_bestSolution("pearls", 513, "Josef Peterka")
-node_bestSolution("turtle", 1950, "Josef Peterka")
+node_bestSolution("pearls", 487, "Gabor Braun")
+node_bestSolution("turtle", 688, "Josef Peterka")
  
 node_bestSolution("computer", 156, "Josef Peterka")
 node_bestSolution("noground", 44, "Heiko Luettges")
@@ -46,35 +46,41 @@ node_bestSolution("bathroom", 90, "Josef Peterka")
 node_bestSolution("duckie", 98, "Ronny Standtke")
 node_bestSolution("puzzle", 144, "Josef Peterka")
 node_bestSolution("dump", 426, "Josef Peterka")
-node_bestSolution("barrel", 3238, "Josef Peterka")
+node_bestSolution("barrel", 1364, "Gabor Braun")
  
 node_bestSolution("cabin1", 168, "Pavel Danihelka")
 node_bestSolution("snowman", 66, "Pavel Danihelka")
 node_bestSolution("cannons", 39, "Pavel Danihelka")
 node_bestSolution("kitchen", 564, "Josef Peterka")
-node_bestSolution("cabin2", 395, "Gabor Braun")
-node_bestSolution("captain", 571, "Tibor Zenis")
-node_bestSolution("map", 2610, "Josef Peterka")
+node_bestSolution("cabin2", 387, "Brian Raiter")
+node_bestSolution("captain", 539, "Gabor Braun")
+node_bestSolution("map", 1541, "Gabor Braun")
  
 node_bestSolution("reactor", 163, "Pavel Danihelka")
 node_bestSolution("magnet", 408, "Josef Peterka")
 node_bestSolution("engine", 256, "Gabor Braun")
 node_bestSolution("steel", 185, "Josef Peterka")
 node_bestSolution("corridor", 528, "Gabor Braun")
-node_bestSolution("experiments", 728, "Gabor Braun")
-node_bestSolution("propulsion", 3634, "Josef Peterka")
+node_bestSolution("experiments", 714, "Gabor Braun")
+node_bestSolution("propulsion", 2046, "Gabor Braun")
  
 node_bestSolution("aztec", 376, "Mark Byers")
 node_bestSolution("gems", 59, "Mark Byers")
-node_bestSolution("chest", 287, "Gabor Braun")
+node_bestSolution("chest", 279, "Gabor Braun")
 node_bestSolution("alibaba", 459, "Gabor Braun")
 node_bestSolution("cave", 186, "Josef Peterka")
-node_bestSolution("grail", 3120, "Josef Peterka")
+node_bestSolution("grail", 1725, "Gabor Braun")
  
 node_bestSolution("tetris", 134, "Gabor Braun")
 node_bestSolution("emulator", 620, "Gabor Braun")
 node_bestSolution("warcraft", 573, "Josef Peterka")
-node_bestSolution("windoze", 565, "Gabor Braun")
+node_bestSolution("windoze", 553, "Gabor Braun")
 node_bestSolution("hardware", 635, "Gabor Braun")
-node_bestSolution("floppy", 1948, "Josef Peterka")
+node_bestSolution("floppy", 998, "Gabor Braun")
  
+node_bestSolution("hanoi", 432, "Miroslav Olšák")
+node_bestSolution("rush", 852, "Miroslav Olšák")
+node_bestSolution("fdto", 251, "Ronny Standtke")
+--node_bestSolution("rotate", 213, "Miroslav Olsak")
+--node_bestSolution("nowall", 566, "Miroslav Olsak")
+--node_bestSolution("hole", 499, "Miroslav Olsak")
